#
# spec file for package perl-Business-CreditCard
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           perl-Business-CreditCard
Version:        0.36
Release:        1.1
%define cpan_name Business-CreditCard
Summary:        Validate/generate credit card checksums/names
License:        Artistic-1.0 or GPL-1.0+
Group:          Development/Libraries/Perl
Url:            http://search.cpan.org/dist/Business-CreditCard/
Source0:        http://www.cpan.org/authors/id/I/IV/IVAN/%{cpan_name}-%{version}.tar.gz
Source1:        cpanspec.yml
BuildArch:      noarch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  perl
BuildRequires:  perl-macros
%{perl_requires}

%description
These subroutines tell you whether a credit card number is self-consistent
-- whether the last digit of the number is a valid checksum for the
preceding digits.

The validate() subroutine returns 1 if the card number provided passes the
checksum test, and 0 otherwise.

The cardtype() subroutine returns a string containing the type of card. The
list of possible return values is more comprehensive than it used to be,
but additions are still most welcome.

Possible return values are:

  VISA card
  MasterCard
  Discover card
  American Express card
  enRoute
  JCB
  BankCard
  Switch
  Solo
  China Union Pay
  Laser
  Isracard
  Unknown

"Not a credit card" is returned on obviously invalid data values.

Versions before 0.31 may also have returned "Diner's Club/Carte Blanche"
(these cards are now recognized as "Discover card").

As of 0.30, cardtype() will accept a partial card masked with "x", "X',
".", "*" or "_". Only the first 2-6 digits and the length are significant;
whitespace and dashes are removed. With two digits, Visa, MasterCard,
Discover and Amex are recognized (versions before 0.36 needed four digits
to recognize all Discover cards). With four digits, almost all cards except
some Switch cards are recognized. With six digits (the full "BIN" or
"IIN"), all cards are recognized. Six digits are also required for
receipt_cardtype().

The generate_last_digit() subroutine computes and returns the last digit of
the card given the preceding digits. With a 16-digit card, you provide the
first 15 digits; the subroutine returns the sixteenth.

This module does _not_ tell you whether the number is on an actual card,
only whether it might conceivably be on a real card. To verify whether a
card is real, or whether it's been stolen, or to actually process charges,
you need a Merchant account. See Business::OnlinePayment.

These subroutines will also work if you provide the arguments as numbers
instead of strings, e.g. 'validate(5276440065421319)'.

%prep
%setup -q -n %{cpan_name}-%{version}

%build
%{__perl} Makefile.PL INSTALLDIRS=vendor
%{__make} %{?_smp_mflags}

%check
%{__make} test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%defattr(-,root,root,755)
%doc BINS Changes README

%changelog
* Thu Jun 23 2016 coolo@suse.com
- updated to 0.36
  see /usr/share/doc/packages/perl-Business-CreditCard/Changes
  0.36  Tue Jun 14 11:36:05 PDT 2016
  - Allow (and doc) import of receipt_cardtype
  - validate_card() is a new synonym for validate(), starting a long-term
    plan to stop exporting validate() or anything else by default.
  - Best-effort cardtype() when only the first two digits are available
    (identify masked 60xx as Discover)
* Sat Feb 13 2016 coolo@suse.com
- updated to 0.35
  see /usr/share/doc/packages/perl-Business-CreditCard/Changes
  0.35  Tue Feb  9 14:43:38 PST 2016
  - Fix bug identifying 49* Visa cards introduced in 0.34, patch from
    Ed J, thanks!
  - doc: Clarify processing agreements don't apply to Canada
* Sun Feb  7 2016 coolo@suse.com
- updated to 0.34
  see /usr/share/doc/packages/perl-Business-CreditCard/Changes
  0.34  Fri Feb  5 07:24:00 PST 2016
  - 19 digit Visa and Discover cards
  - MasterCard 222100–272099 range
  - Canada does not process JCB 3529-3589 as Discover, but Puerto Rico,
    US Virgin Islans, Northern Mariana Islands, Palau and Guam do
  - China Union Pay only processed as Discover in the US, Mexico and
    the Caribbean, not elsewhere outside China
  - 14 digit Discover remain only in 36*
  - receipt_cardtype subroutine supporting Discover's new receipt
    requirements
* Mon Apr 13 2015 coolo@suse.com
- updated to 0.33
  see /usr/share/doc/packages/perl-Business-CreditCard/Changes
  0.33  Sat Sep 13 16:13:15 PDT 2014
  - With $Country explicity to CA, fix identification of JCB 3529-3589
    as Discover
  - Allow use of our subroutines as class methods, patch from Adam
    Kennedy, thanks!
  - Add tests for processing agreement / country functionality
  0.32  Thu Feb 21 16:02:42 PST 2013
  - Add Israeli Isracard (no checksum yet)
  - Add LICENSE=>perl to Makefile.PL; add license to META.yml,
    closes: cpan #27735
  - Documentation: Add link to Neil Bowers' review of CC check modules
  - Rearrange cardtype() for performance
  - Fix Discover identification of 39 and 3529-3589 prefixes, patch from
    Jason Terry, thanks!
* Tue May  3 2011 coolo@opensuse.org
- initial package 0.31
  * created by cpanspec 1.78.04
